# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seqq.models.v1alpha_list_searches_response import V1alphaListSearchesResponse

class TestV1alphaListSearchesResponse(unittest.TestCase):
    """V1alphaListSearchesResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V1alphaListSearchesResponse:
        """Test V1alphaListSearchesResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `V1alphaListSearchesResponse`
        """
        model = V1alphaListSearchesResponse()
        if include_optional:
            return V1alphaListSearchesResponse(
                searches = [
                    seqq.models.v1alpha_search.v1alphaSearch(
                        name = '', 
                        query = '', 
                        code = 'CODE_UNSPECIFIED', 
                        prefix = '', 
                        query_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        query_duration = '', 
                        hits = [
                            seqq.models.v1alpha_hit.v1alphaHit(
                                saccver = '', 
                                pident = 1.337, 
                                length = '', 
                                mismatch = '', 
                                gapopen = '', 
                                qstart = '', 
                                qend = '', 
                                sstart = '', 
                                send = '', 
                                evalue = 1.337, 
                                bitscore = 1.337, )
                            ], 
                        state = 'STATE_UNSPECIFIED', 
                        error = seqq.models.rpc_status.rpcStatus(
                            message = '', 
                            details = [
                                {
                                    'key' : None
                                    }
                                ], ), 
                        blastn = seqq.models.v1alpha_blastn.v1alphaBlastn(), 
                        blastp = seqq.models.v1alpha_blastp.v1alphaBlastp(), 
                        blastx = seqq.models.v1alpha_blastp.v1alphaBlastp(), 
                        tblastn = seqq.models.v1alpha_tblastn.v1alphaTblastn(), 
                        tblastx = seqq.models.v1alpha_tblastx.v1alphaTblastx(), )
                    ],
                next_page_token = ''
            )
        else:
            return V1alphaListSearchesResponse(
        )
        """

    def testV1alphaListSearchesResponse(self):
        """Test V1alphaListSearchesResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
