# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class SearchState(str, Enum):
    """
    The current state of the Search.   - STATE_UNSPECIFIED: STATE_UNSPECIFIED is the default value.  - RUNNING: RUNNING is the search is running.  - SUCCEEDED: SUCCEEDED is the search succeeded.  - FAILED: FAILED is the search failed.
    """

    """
    allowed enum values
    """
    STATE_UNSPECIFIED = 'STATE_UNSPECIFIED'
    RUNNING = 'RUNNING'
    SUCCEEDED = 'SUCCEEDED'
    FAILED = 'FAILED'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SearchState from a JSON string"""
        return cls(json.loads(json_str))


