# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seqq.models.v1alpha_list_integrations_response import V1alphaListIntegrationsResponse

class TestV1alphaListIntegrationsResponse(unittest.TestCase):
    """V1alphaListIntegrationsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V1alphaListIntegrationsResponse:
        """Test V1alphaListIntegrationsResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `V1alphaListIntegrationsResponse`
        """
        model = V1alphaListIntegrationsResponse()
        if include_optional:
            return V1alphaListIntegrationsResponse(
                integrations = [
                    seqq.models.v1alpha_integration.v1alphaIntegration(
                        collection = '', 
                        name = '', 
                        sequence_id_prefix = '', 
                        etag = '', 
                        ncbi = seqq.models.v1alpha_integration_ncbi.v1alphaIntegrationNCBI(
                            manifest = '', 
                            uploads = {
                                'key' : ''
                                }, ), 
                        google_drive = seqq.models.v1alpha_integration_google_drive.v1alphaIntegrationGoogleDrive(
                            service_account_credentials = 'YQ==', ), )
                    ],
                next_page_token = ''
            )
        else:
            return V1alphaListIntegrationsResponse(
        )
        """

    def testV1alphaListIntegrationsResponse(self):
        """Test V1alphaListIntegrationsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
