# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seqq.models.v1alpha_integration_google_drive import V1alphaIntegrationGoogleDrive

class TestV1alphaIntegrationGoogleDrive(unittest.TestCase):
    """V1alphaIntegrationGoogleDrive unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V1alphaIntegrationGoogleDrive:
        """Test V1alphaIntegrationGoogleDrive
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `V1alphaIntegrationGoogleDrive`
        """
        model = V1alphaIntegrationGoogleDrive()
        if include_optional:
            return V1alphaIntegrationGoogleDrive(
                service_account_credentials = 'YQ=='
            )
        else:
            return V1alphaIntegrationGoogleDrive(
        )
        """

    def testV1alphaIntegrationGoogleDrive(self):
        """Test V1alphaIntegrationGoogleDrive"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
