# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seqq.api.seqq_service_api import SeqqServiceApi


class TestSeqqServiceApi(unittest.TestCase):
    """SeqqServiceApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SeqqServiceApi()

    def tearDown(self) -> None:
        pass

    def test_batch_create_sequences(self) -> None:
        """Test case for batch_create_sequences

        Create a batch of Sequences in a Collection.
        """
        pass

    def test_create_collection(self) -> None:
        """Test case for create_collection

        Create a Collection.
        """
        pass

    def test_create_integration(self) -> None:
        """Test case for create_integration

        Create an Integration.
        """
        pass

    def test_create_sequence(self) -> None:
        """Test case for create_sequence

        Create a Sequence in a Collection.
        """
        pass

    def test_delete_collection(self) -> None:
        """Test case for delete_collection

        Delete a Collection by name.
        """
        pass

    def test_delete_integration(self) -> None:
        """Test case for delete_integration

        Delete an Integration by name.
        """
        pass

    def test_delete_search(self) -> None:
        """Test case for delete_search

        Delete a Search by name.
        """
        pass

    def test_delete_sequence(self) -> None:
        """Test case for delete_sequence

        Delete a Sequence by name.
        """
        pass

    def test_get_collection(self) -> None:
        """Test case for get_collection

        Get a Collection by its name.
        """
        pass

    def test_get_integration(self) -> None:
        """Test case for get_integration

        Get an Integration by name.
        """
        pass

    def test_get_search(self) -> None:
        """Test case for get_search

        Get a Search by name.
        """
        pass

    def test_get_sequence(self) -> None:
        """Test case for get_sequence

        Get a Sequence by name.
        """
        pass

    def test_list_collections(self) -> None:
        """Test case for list_collections

        List Collections.
        """
        pass

    def test_list_integrations(self) -> None:
        """Test case for list_integrations

        List Integrations in a Collection.
        """
        pass

    def test_list_searches(self) -> None:
        """Test case for list_searches

        List Searches in a Collection.
        """
        pass

    def test_list_sequences(self) -> None:
        """Test case for list_sequences

        List Sequences in a Collection.
        """
        pass

    def test_start_search(self) -> None:
        """Test case for start_search

        Start a Search asynchronously.
        """
        pass

    def test_update_integration(self) -> None:
        """Test case for update_integration

        Update an Integration.
        """
        pass


if __name__ == '__main__':
    unittest.main()
