# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seqq.models.v1alpha_create_sequences_from_file_response import V1alphaCreateSequencesFromFileResponse

class TestV1alphaCreateSequencesFromFileResponse(unittest.TestCase):
    """V1alphaCreateSequencesFromFileResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V1alphaCreateSequencesFromFileResponse:
        """Test V1alphaCreateSequencesFromFileResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `V1alphaCreateSequencesFromFileResponse`
        """
        model = V1alphaCreateSequencesFromFileResponse()
        if include_optional:
            return V1alphaCreateSequencesFromFileResponse(
                sequences = [
                    seqq.models.v1alpha_sequence.v1alphaSequence(
                        name = '', 
                        collection = '', 
                        sequence = '', 
                        code = 'CODE_UNSPECIFIED', 
                        taxonomy_id = '', 
                        create_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        etag = '', 
                        description = '', )
                    ]
            )
        else:
            return V1alphaCreateSequencesFromFileResponse(
        )
        """

    def testV1alphaCreateSequencesFromFileResponse(self):
        """Test V1alphaCreateSequencesFromFileResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
