# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seqq.models.v1alpha_file_encoding import V1alphaFileEncoding

class TestV1alphaFileEncoding(unittest.TestCase):
    """V1alphaFileEncoding unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testV1alphaFileEncoding(self):
        """Test V1alphaFileEncoding"""
        # inst = V1alphaFileEncoding()

if __name__ == '__main__':
    unittest.main()
