# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class V1alphaFileEncoding(str, Enum):
    """
    FileEncoding is the type of sequence file to upload.   - FILE_UNSPECIFIED: FILE_UNSPECIFIED is the default value.  - FASTA: FASTA is a FASTA file.  - GENBANK: GEBANK is a GenBank file.
    """

    """
    allowed enum values
    """
    FILE_UNSPECIFIED = 'FILE_UNSPECIFIED'
    FASTA = 'FASTA'
    GENBANK = 'GENBANK'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of V1alphaFileEncoding from a JSON string"""
        return cls(json.loads(json_str))


