# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class V1alphaCode(str, Enum):
    """
    Code is the type of sequence.   - CODE_UNSPECIFIED: CODE_UNSPECIFIED is the default value.  - NUCLEIC: NUCLEIC is a nucleic acid sequence.  - PROTEIN: PROTEIN is an amino acid sequence.
    """

    """
    allowed enum values
    """
    CODE_UNSPECIFIED = 'CODE_UNSPECIFIED'
    NUCLEIC = 'NUCLEIC'
    PROTEIN = 'PROTEIN'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of V1alphaCode from a JSON string"""
        return cls(json.loads(json_str))


